'use client'

import React from 'react';

import { usePlyr } from 'plyr-react';

import style from './PlyrJS.module.scss'

import { VideoData } from '@/meta/data';

import "plyr-react/plyr.css"

import dynamic from 'next/dynamic';

interface Props {
    data: VideoData
}

const PlyrJS: React.FC<Props> = (props) => {

    const PlyrComponent = React.useMemo(() => {
        return dynamic(() => import("plyr-react").then(() => {
            const Comp = React.forwardRef((props, ref) => {
                //@ts-ignore
                const { source, options = null, ...rest } = props
                //@ts-ignore
                const raptorRef = usePlyr(ref, {
                    source,
                    options,
                })
                return <video ref={raptorRef} className="plyr-react plyr" {...rest} />
            })

            Comp.displayName = 'PlyrComponent'

            return Comp;
        }), { ssr: false });
    }, []);

    PlyrComponent.displayName = 'PlyrComponent'

    const { data } = props;

    const plyrProps = {
        source: { type: 'video', sources: data.srcSet }, // https://github.com/sampotts/plyr#the-source-setter
        options: {
            controls: [
                'play-large',
                'play', // Play/pause playback
                'progress', // The progress bar and scrubber for playback and buffering
                'current-time', // The current time of playback
                'duration', // The full duration of the media
                'mute', // Toggle mute
                'volume', // Volume control
                'captions', // Toggle captions
                'settings', // Settings menu
                'fullscreen', // Toggle fullscreen
            ]
        }, // https://github.com/sampotts/plyr#options
    }

    return (
        <div className={style.container}>
            {/* @ts-ignore */}
            <PlyrComponent {...plyrProps} />
        </div>
    );

};

export default PlyrJS;