import { YOUPORN_BASE_URL, YOUPORN_BASE_URL_VIDEO } from "@/constants/urls";
import { FetchParams, GalleryData, VideoData, VideoSourceItem } from "@/meta/data";
import { getHeaders } from "../common/headers";
import { getDataFromRedis, storeDataIntoRedis } from "@/redis/client";
import { DEFAULT_RELATED_VIDEO_KEY_PATH, DEFAULT_YOUPORN_VIDEO_EXPIRY, DEFAULT_YOUPORN_GALLERY_EXPIRY } from "@/constants/redis";

import * as cheerio from "cheerio";

import axios, { AxiosError } from "axios";
import { createSessionCookie, findGetMediaUrlInTagblock } from "../common/mindgeek";
import { getYouPornMediaUrlList } from "./url";
import { Platforms } from "@/meta/settings";

export const fetchYouPornVideoData = async (videoId: string, params?: FetchParams): Promise<[VideoData, GalleryData[]]> => {

    let data: VideoData = {
        hlsUrl: '',
        srcSet: []
    }

    let relatedData: GalleryData[] = [];

    let mediaUrl, sessionCookie, convertedData: VideoSourceItem[]

    let reqHeaders = getHeaders(YOUPORN_BASE_URL)

    const queryUrl = `${YOUPORN_BASE_URL_VIDEO}/${videoId.replace(/\//g, '')}`

    const cachedVideoData = await getDataFromRedis(queryUrl)
    const cachedRelatedData = await getDataFromRedis(queryUrl + DEFAULT_RELATED_VIDEO_KEY_PATH)

    if (cachedVideoData) {
        return [cachedVideoData as VideoData, cachedRelatedData as GalleryData[] ?? []]
    }

    await axios.get(queryUrl, reqHeaders)

    .then(async response => {

        sessionCookie = response?.headers["set-cookie"] ? createSessionCookie(response?.headers["set-cookie"]) : '';

        const html = response.data;

        const $ = cheerio.load(html);

        const scriptTags = $("script");

        scriptTags.map((idx, elem) => {
            const getMediaUrl = findGetMediaUrlInTagblock($(elem).toString().replace(/\\/g, ''), 'media/mp4') ?? null

            if (getMediaUrl) {
                mediaUrl = getMediaUrl
            }

        })

        const wrapperId = "#relatedVideos .video-box"
    
        const thumbs = $(wrapperId);
    
        thumbs.map((key, thumb) => {
    
            const videoUrl = $(thumb).find("a.tm_video_link").attr("href")?.split('/')[2];
            const imgUrl = $(thumb).find("img.thumb-image").attr("data-src")
            const text = $(thumb).find("a.video-title").text();
    
            videoUrl && imgUrl && text && relatedData.push({
                videoUrl,
                imgUrl,
                text,
                platform: Platforms.youporn
            })
        })

    }).catch((error: AxiosError) => {
        // error handling goes here
    });

    if (sessionCookie && mediaUrl) {
        convertedData = await getYouPornMediaUrlList(mediaUrl, sessionCookie)
        data.srcSet = convertedData.reverse()

        await storeDataIntoRedis(queryUrl, data, DEFAULT_YOUPORN_VIDEO_EXPIRY);
    }

    if (relatedData.length > 0) {
        await storeDataIntoRedis(queryUrl + DEFAULT_RELATED_VIDEO_KEY_PATH, relatedData, DEFAULT_YOUPORN_GALLERY_EXPIRY);
    }

    return [ data, relatedData ]
}